diff cropresize/__init__.py @ 4:6ec33e2ce60f

more documentation
author k0s <k0scist@gmail.com>
date Sat, 06 Mar 2010 13:22:31 -0500
parents 0a54e5bd2875
children c89738f3f417
line wrap: on
line diff
--- a/cropresize/__init__.py	Sat Mar 06 13:11:46 2010 -0500
+++ b/cropresize/__init__.py	Sat Mar 06 13:22:31 2010 -0500
@@ -6,10 +6,14 @@
 def crop_resize(image, size, exact_size=False):
     """
     Crop out the proportional middle of the image and set to the desired size.
+    * image: a PIL image object
+    * size: a 2-tuple of (width,height);  at least one must be specified
+    * exact_size: whether to scale up for smaller images
     If the image is bigger than the sizes passed, this works as expected.
     If the image is smaller than the sizes passed, then behavior is dictated
-    by the `exact_size` flag.  If the 
-
+    by the ``exact_size`` flag.  If the ``exact_size`` flag is false,
+    the image will be returned unmodified.  If the ``exact_size`` flag is true,
+    the image will be scaled up to the required size.
     """
     assert size[0] or size[1]
 
@@ -47,7 +51,7 @@
 
 def main():
     from optparse import OptionParser
-    parser = OptionParser()
+    parser = OptionParser('%prog [options] image1.png [image2.jpg] [...]')
     parser.add_option('-W', '--width')
     parser.add_option('-H', '--height')
     parser.add_option('-e', '--exact-size', dest='exact', action='store_true', default=False)